==> pcaMethods_1.32.0.zip: pcaMethods/doc/missingValues.R <==
###################################################
### chunk number 1: 
###################################################
#line 44 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfMb79e/R.INSTALL789526ed/pcaMethods/inst/doc/missingValues.Rnw"
library(pcaMethods)


###################################################
### chunk number 2: 
###################################################
#line 47 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfMb79e/R.INSTALL789526ed/pcaMethods/inst/doc/missingValues.Rnw"
data(metaboliteData)
mD <- metaboliteData
sum(is.na(mD))


###################################################
### chunk number 3: 
###################################################
#line 53 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfMb79e/R.INSTALL789526ed/pcaMethods/inst/doc/missingValues.Rnw"
pc <- pca(mD, nPcs=3, method="ppca")
imputed <- completeObs(pc)


###################################################
### chunk number 4: 
###################################################
#line 59 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfMb79e/R.INSTALL789526ed/pcaMethods/inst/doc/missingValues.Rnw"
data(metaboliteDataComplete)
mdComp <- metaboliteDataComplete
sum((mdComp[is.na(mD)] - imputed[is.na(mD)])^2) / sum(mdComp[is.na(mD)]^2)


###################################################
### chunk number 5: 
###################################################
#line 65 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfMb79e/R.INSTALL789526ed/pcaMethods/inst/doc/missingValues.Rnw"
imputedNipals <- completeObs(pca(mD, nPcs=3, method="nipals"))
sum((mdComp[is.na(mD)] - imputedNipals[is.na(mD)])^2) / sum(mdComp[is.na(mD)]^2)


###################################################
### chunk number 6: 
###################################################
#line 72 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfMb79e/R.INSTALL789526ed/pcaMethods/inst/doc/missingValues.Rnw"
library(Biobase)
data(sample.ExpressionSet)
exSet <- sample.ExpressionSet
exSetNa <- exSet
exprs(exSetNa)[sample(13000, 200)] <- NA
lost <- is.na(exprs(exSetNa))
pc <- pca(exSetNa, nPcs=2, method="ppca")
impExSet <- asExprSet(pc, exSetNa)
sum((exprs(exSet)[lost] - exprs(impExSet)[lost])^2) / sum(exprs(exSet)[lost]^2)

==> pcaMethods_1.36.0.zip: pcaMethods/doc/missingValues.R <==
###################################################
### chunk number 1: 
###################################################
#line 44 "missingValues.Rnw"
library(pcaMethods)


###################################################
### chunk number 2: 
###################################################
#line 47 "missingValues.Rnw"
data(metaboliteData)
mD <- metaboliteData
sum(is.na(mD))


###################################################
### chunk number 3: 
###################################################
#line 53 "missingValues.Rnw"
pc <- pca(mD, nPcs=3, method="ppca")
imputed <- completeObs(pc)


###################################################
### chunk number 4: 
###################################################
#line 59 "missingValues.Rnw"
data(metaboliteDataComplete)
mdComp <- metaboliteDataComplete
sum((mdComp[is.na(mD)] - imputed[is.na(mD)])^2) / sum(mdComp[is.na(mD)]^2)


###################################################
### chunk number 5: 
###################################################
#line 65 "missingValues.Rnw"
imputedNipals <- completeObs(pca(mD, nPcs=3, method="nipals"))
sum((mdComp[is.na(mD)] - imputedNipals[is.na(mD)])^2) / sum(mdComp[is.na(mD)]^2)


###################################################
### chunk number 6: 
###################################################
#line 72 "missingValues.Rnw"
library(Biobase)
data(sample.ExpressionSet)
exSet <- sample.ExpressionSet
exSetNa <- exSet
exprs(exSetNa)[sample(13000, 200)] <- NA
lost <- is.na(exprs(exSetNa))
pc <- pca(exSetNa, nPcs=2, method="ppca")
impExSet <- asExprSet(pc, exSetNa)
sum((exprs(exSet)[lost] - exprs(impExSet)[lost])^2) / sum(exprs(exSet)[lost]^2)
